@@ -45,13 +45,13 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-VERSION = (2, 7, 3, 9)
+VERSION = (2, 7, 3, 10)
 __version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
 __maintainer__ = 'Ask Solem',
 __contact__ = "ask@celeryproject.org"
-__homepage__ = "http://github.com/ask/billiard"
+__homepage__ = "http://github.com/celery/billiard"
 __docformat__ = "restructuredtext"
 
 # -eof meta-
