@@ -1,6 +1,7 @@
+from __future__ import absolute_import
+
 import errno
 import os
-import sys
 
 try:
     bytes = bytes
